==> jc-1.4.0.tar.gz: gnu/java/security/provider/CollectionCertStoreImpl.h <==
// public final class gnu.java.security.provider.CollectionCertStoreImpl

// class file dependencies
// @dep_class 1002b95b2b7c834 gnu_java_security_provider_CollectionCertStoreImpl
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ef1da2cce024fd8d java_security_cert_CertStoreSpi

// header file dependencies
// @dep_header java_security_cert_CertStoreSpi

#include "java/security/cert/CertStoreSpi.h"

#ifndef _JC_gnu_java_security_provider_CollectionCertStoreImpl_H_
#define _JC_gnu_java_security_provider_CollectionCertStoreImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_cert_CRLSelector$object;
struct _jc_java_security_cert_CertSelector$object;
struct _jc_java_security_cert_CertStoreParameters$object;
struct _jc_java_util_Collection$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_refs	_jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_refs;
typedef struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_nonrefs	_jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$refs	_jc_gnu_java_security_provider_CollectionCertStoreImpl$refs;
typedef struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$nonrefs	_jc_gnu_java_security_provider_CollectionCertStoreImpl$nonrefs;
typedef struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object	_jc_gnu_java_security_provider_CollectionCertStoreImpl$object;

typedef const struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$vmethods	_jc_gnu_java_security_provider_CollectionCertStoreImpl$vmethods;
typedef const struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$vtable	_jc_gnu_java_security_provider_CollectionCertStoreImpl$vtable;
typedef const struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$vtype	_jc_gnu_java_security_provider_CollectionCertStoreImpl$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_CollectionCertStoreImpl$method$_init$5fa483d00d0d58c4(_jc_env *, struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_provider_CollectionCertStoreImpl$method$engineGetCRLs$e3a5332aca694ad3(_jc_env *, struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object *, struct _jc_object *);
extern struct _jc_object *_jc_gnu_java_security_provider_CollectionCertStoreImpl$method$engineGetCertificates$6e8d101a752c150d(_jc_env *, struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_CollectionCertStoreImpl$method_info$engineGetCRLs$e3a5332aca694ad3;
extern _jc_method _jc_gnu_java_security_provider_CollectionCertStoreImpl$method_info$engineGetCertificates$6e8d101a752c150d;

// Virtual methods structure
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$vmethods {
	struct _jc_object	*(*engineGetCRLs$e3a5332aca694ad3)(_jc_env *, struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object *, struct _jc_object *);
	struct _jc_object	*(*engineGetCertificates$6e8d101a752c150d)(_jc_env *, struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertStoreSpi$vmethods	java_security_cert_CertStoreSpi;
	_jc_gnu_java_security_provider_CollectionCertStoreImpl$vmethods	gnu_java_security_provider_CollectionCertStoreImpl;
};

// Vtype
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_CollectionCertStoreImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_refs {
	struct _jc_object	*store;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$refs {
    _jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_refs	gnu_java_security_provider_CollectionCertStoreImpl;
    _jc_java_security_cert_CertStoreSpi$sub_refs	java_security_cert_CertStoreSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertStoreSpi$sub_nonrefs	java_security_cert_CertStoreSpi;
    _jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_nonrefs	gnu_java_security_provider_CollectionCertStoreImpl;
};

// Object instance structure
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object {
	_jc_gnu_java_security_provider_CollectionCertStoreImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_CollectionCertStoreImpl$vtype	*vtype;
	_jc_gnu_java_security_provider_CollectionCertStoreImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_CollectionCertStoreImpl$vtype _jc_gnu_java_security_provider_CollectionCertStoreImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_CollectionCertStoreImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_CollectionCertStoreImpl$class_object;

#endif	/* _JC_gnu_java_security_provider_CollectionCertStoreImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/CollectionCertStoreImpl.h <==
// public final class gnu.java.security.provider.CollectionCertStoreImpl

// class file dependencies
// @dep_class 7ad0b8a15aa77e32 gnu_java_security_provider_CollectionCertStoreImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ef1da2cce024fd8d java_security_cert_CertStoreSpi

// header file dependencies
// @dep_header java_security_cert_CertStoreSpi

#include "java/security/cert/CertStoreSpi.h"

#ifndef _JC_gnu_java_security_provider_CollectionCertStoreImpl_H_
#define _JC_gnu_java_security_provider_CollectionCertStoreImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_cert_CRLSelector$object;
struct _jc_java_security_cert_CertSelector$object;
struct _jc_java_security_cert_CertStoreParameters$object;
struct _jc_java_util_Collection$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_refs	_jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_refs;
typedef struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_nonrefs	_jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$refs	_jc_gnu_java_security_provider_CollectionCertStoreImpl$refs;
typedef struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$nonrefs	_jc_gnu_java_security_provider_CollectionCertStoreImpl$nonrefs;
typedef struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object	_jc_gnu_java_security_provider_CollectionCertStoreImpl$object;

typedef const struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$vmethods	_jc_gnu_java_security_provider_CollectionCertStoreImpl$vmethods;
typedef const struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$vtable	_jc_gnu_java_security_provider_CollectionCertStoreImpl$vtable;
typedef const struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$vtype	_jc_gnu_java_security_provider_CollectionCertStoreImpl$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_CollectionCertStoreImpl$method$_init$5fa483d00d0d58c4(_jc_env *, struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_provider_CollectionCertStoreImpl$method$engineGetCRLs$e3a5332aca694ad3(_jc_env *, struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_provider_CollectionCertStoreImpl$method$engineGetCertificates$6e8d101a752c150d(_jc_env *, struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_CollectionCertStoreImpl$method_info$engineGetCRLs$e3a5332aca694ad3;
extern _jc_method _jc_gnu_java_security_provider_CollectionCertStoreImpl$method_info$engineGetCertificates$6e8d101a752c150d;

// Virtual methods structure
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$vmethods {
	struct _jc_object	*(*engineGetCRLs$e3a5332aca694ad3)(_jc_env *, struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineGetCertificates$6e8d101a752c150d)(_jc_env *, struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertStoreSpi$vmethods	java_security_cert_CertStoreSpi;
	_jc_gnu_java_security_provider_CollectionCertStoreImpl$vmethods	gnu_java_security_provider_CollectionCertStoreImpl;
};

// Vtype
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_CollectionCertStoreImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_refs {
	struct _jc_object	*store;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$refs {
    _jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_refs	gnu_java_security_provider_CollectionCertStoreImpl;
    _jc_java_security_cert_CertStoreSpi$sub_refs	java_security_cert_CertStoreSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertStoreSpi$sub_nonrefs	java_security_cert_CertStoreSpi;
    _jc_gnu_java_security_provider_CollectionCertStoreImpl$sub_nonrefs	gnu_java_security_provider_CollectionCertStoreImpl;
};

// Object instance structure
struct _jc_gnu_java_security_provider_CollectionCertStoreImpl$object {
	_jc_gnu_java_security_provider_CollectionCertStoreImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_CollectionCertStoreImpl$vtype	*vtype;
	_jc_gnu_java_security_provider_CollectionCertStoreImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_CollectionCertStoreImpl$vtype _jc_gnu_java_security_provider_CollectionCertStoreImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_CollectionCertStoreImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_CollectionCertStoreImpl$class_object;

#endif	/* _JC_gnu_java_security_provider_CollectionCertStoreImpl_H_ */
